OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "嵌入式消息 %s",
    "Important mail" : "重要邮件",
    "Unread mail" : "未读邮件",
    "Important" : "重要",
    "Work" : "工作",
    "Personal" : "个人",
    "To Do" : "要做的事",
    "Later" : "稍晚",
    "Mails" : "邮件",
    "Mail" : "邮件",
    "💌 A mail app for Nextcloud" : "💌 Nextcloud 上的一款邮件应用",
    "Drafts are saved in:" : "草稿邮件被保存于：",
    "Sent messages are saved in:" : "已发送邮件被保存于：",
    "Deleted messages are moved in:" : "已删除邮件被移动到：",
    "Auto" : "自动",
    "Name" : "姓名",
    "Mail address" : "邮箱",
    "Password" : "密码",
    "Manual" : "手动",
    "IMAP Settings" : "IMAP 设置",
    "IMAP Host" : "IMAP 主机",
    "IMAP Security" : "IMAP 安全",
    "None" : "无",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP 端口",
    "IMAP User" : "IMAP 用户",
    "IMAP Password" : "IMAP 密码",
    "SMTP Settings" : "SMTP 设置",
    "SMTP Host" : "SMTP 主机",
    "SMTP Security" : "SMTP 安全",
    "SMTP Port" : "SMTP 端口",
    "SMTP User" : "SMTP 用户",
    "SMTP Password" : "SMTP 密码",
    "Connecting" : "正在连接",
    "Save" : "保存",
    "Connect" : "连接",
    "Account settings" : "账号设置",
    "Change name" : "更改名称",
    "Signature" : "签名",
    "A signature is added to the text of new messages and replies." : "签名已加入到 新消息 及 回复消息 的文本中。",
    "Writing mode" : "编写模式",
    "Preferred writing mode for new messages and replies." : "编写 新消息 及 回复消息 的偏好模式。",
    "Default folders" : "默认文件夹",
    "Sieve filter rules" : "Sieve 过滤器规则",
    "Trusted senders" : "信任的发件人",
    "Mail server" : "邮件服务器",
    "Sieve filter server" : "Sieve 过滤器服务器",
    "Update alias" : "更新别名",
    "Show update alias form" : "显示更新别名表单",
    "Delete alias" : "删除别名",
    "Email address" : "电子邮件地址",
    "Add alias" : "添加别名",
    "Create alias" : "创建别名",
    "Cancel" : "取消",
    "Add mail account" : "添加邮件账号",
    "Use Gravatar and favicon avatars" : "使用 Gravatar 和 favicon 形象",
    "Register as application for mail links" : "注册为邮件链接应用",
    "Show keyboard shortcuts" : "显示键盘快捷方式",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "允许该应用收集有关您的互动的数据。 根据这些数据，该应用程序将适应您的偏好。 数据将仅存储在本地。",
    "Put my text to the bottom of a reply instead of on top of it." : "把我的信息放在回复的最下面，而不是最上面。 ",
    "Automatically classify importance of new email" : "自动分类新邮件的重要性 ",
    "Could not update preference" : "无法更新首选项",
    "From" : "发件人",
    "Select account" : "选择账号",
    "To" : "收件人",
    "Contact or email address …" : "联系人或邮箱地址...",
    "Cc" : "抄送",
    "Bcc" : "密送",
    "No contacts found." : "未找到联系人。",
    "Subject" : "主题",
    "Subject …" : "标题...",
    "This message came from a noreply address so your reply will probably not be read." : "标记的消息来自一个无法回复的地址，您的回复可能不会被阅读。",
    "The following recipients do not have a PGP key: {recipients}." : "以下收件人没有 PGP 密钥：{recipients}。",
    "Write message …" : "编写消息...",
    "Saving draft …" : "正在保存草稿 …",
    "Draft saved" : "草稿已保存",
    "Discard & close draft" : "丢弃并关闭草稿",
    "Upload attachment" : "上传附件",
    "Add attachment from Files" : "从文件添加附件",
    "Enable formatting" : "启用格式化",
    "Request a read receipt" : "请求已读回执",
    "Encrypt message with Mailvelope" : "使用 Mailvelope 加密邮件",
    "Enter a date" : "输入日期",
    "Uploading attachments …" : "正在上传附件…",
    "Sending …" : "正在发送…",
    "Error sending your message" : "发送您的消息时出错",
    "Go back" : "后退",
    "Retry" : "重试",
    "Warning sending your message" : "对发送信息提出警告",
    "Send anyway" : "不论如何都要发送",
    "Message sent!" : "消息已发送！",
    "Add share link from {productName} Files" : "添加来自 {productName} 文件的共享链接",
    "Send" : "发送",
    "Encrypt and send" : "加密并发送",
    "Send unencrypted" : "不加密发送",
    "Message {id} could not be found" : "消息 {id} 未找到",
    "No sent mailbox configured. Please pick one in the account settings." : "没有配置发送邮箱。请在账号设置中选择一个。",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "你在To 和/或 Cc 中正尝试发送给许多收件人。考虑使用 Bcc 来隐藏收件人地址。",
    "Choose a file to add as attachment" : "选择文件添加为附件",
    "Choose a file to share as a link" : "选择要共享的文件作为链接",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["附件超出了允许的附件最大大小 {size}。请通过链接共享文件。"],
    "No message found yet" : "暂无消息",
    "Set up an account" : "设置一个账号",
    "Plain text" : "纯文本",
    "Rich text" : "富文本",
    "No messages in this mailbox" : "此邮箱中没有消息",
    "Draft: " : "草稿: ",
    "Unfavorite" : "取消收藏",
    "Favorite" : "收藏",
    "Read" : "读取",
    "Mark not spam" : "标记为非垃圾邮件",
    "Mark as spam" : "标记为垃圾邮件",
    "Unselect" : "取消选择",
    "Select" : "选择",
    "Edit tags" : "编辑标签",
    "Move" : "移动",
    "Move thread" : "移动线程",
    "Delete thread" : "删除线程",
    "More actions" : "更多操作 ",
    "Edit as new message" : "编辑为新消息",
    "Create event" : "创建事件",
    "Blind copy recipients only" : "仅向收件人发送无信头副本",
    "No trash mailbox configured" : "没有配置垃圾邮箱",
    "Could not delete message" : "无法删除消息",
    "Forward" : "转发",
    "Load more" : "加载更多",
    "_Mark {number} unread_::_Mark {number} unread_" : ["标记 {number} 封未读"],
    "_Mark {number} read_::_Mark {number} read_" : ["标记  {number} 封已读"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["将 {number} 封邮件标记为重要"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["将 {number} 封邮件标记为不重要"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["取消收藏 {number} 封"],
    "_Favorite {number}_::_Favorite {number}_" : ["收藏 {number} 封"],
    "_Unselect {number}_::_Unselect {number}_" : ["取消选中 {number} 封"],
    "_Move {number} thread_::_Move {number} threads_" : ["移动 {number} 个线程"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["转发 {number} 封为附件"],
    "_Delete {number} thread_::_Delete {number} threads_" : ["删除 {number} 个线程"],
    "Report this bug" : "报告此问题",
    "All day" : "全天",
    "Create" : "创建",
    "Event created" : "已创建事件",
    "Could not create event" : "无法建立事件",
    "Comment" : "评论",
    "Accept" : "接受",
    "Decline" : "拒绝",
    "More options" : "更多选项",
    "Could not open mailbox" : "无法打开邮箱",
    "Loading messages …" : "正在加载邮件…",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "正在为您的消息建立索引。 对于较大的邮箱，这可能需要更长的时间。",
    "Choose target mailbox" : "选择目标邮箱",
    "No more submailboxes in here" : "这里已经没有更多子邮箱",
    "Choose" : "选择",
    "Important info" : "重要信息",
    "Other" : "其他",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "根据您与哪些消息互动或手动标记重要消息，消息会自动被标记为重要。在开始的时候，您可能需要手动改变重要性来调教系统，但随着时间的推移，它会不断改进。",
    "The sender of this message has asked to be notified when you read this message." : "此邮件的发送方请求在您阅读此邮件时得到通知。 ",
    "Notify the sender" : "通知发件人",
    "You sent a read confirmation to the sender of this message." : "您向此消息的发送方发送了一个已读确认。",
    "Could not send mdn" : "无法发送 mdn",
    "Reply" : "回复",
    "Reply to sender only" : "只回复发送者",
    "Move message" : "移动消息",
    "View source" : "查看来源",
    "Download thread data for debugging" : "下载线程数据以进行调试",
    "Message source" : "消息来源",
    "Message body" : "消息正文",
    "Import into calendar" : "导入到日历",
    "Download attachment" : "下载附件",
    "Save to Files" : "保存到“文件”",
    "Unnamed" : "未命名",
    "Embedded message" : "嵌入式消息",
    "Choose a folder to store the attachment in" : "选择一个文件夹来存储附件",
    "Save all to Files" : "全部保存到文件",
    "Download Zip" : "下载 Zip",
    "Choose a folder to store the attachments in" : "选择附件保存的目录",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "此消息已使用 PGP 加密。 安装 Mailvelope 对其进行解密。",
    "The images have been blocked to protect your privacy." : "图片已被禁用，以保护您的隐私。",
    "Show images" : "显示图片",
    "Show images temporarily" : "暂时显示图像",
    "Always show images from {sender}" : "始终显示来自 {sender} 的邮件",
    "Always show images from {domain}" : "始终显示来自 {domain} 的图片",
    "Message frame" : "消息框",
    "Quoted text" : "引用文字",
    "Moving" : "移动",
    "Moving thread" : "正在移动线程",
    "Moving message" : "正在移动消息",
    "Quota" : "配额",
    "Show only subscribed mailboxes" : "只显示已订阅的邮箱",
    "Add mailbox" : "添加邮箱",
    "Saving" : "正在保存",
    "Move up" : "上移",
    "Move down" : "下移",
    "Remove account" : "移除账号",
    "Loading …" : "正在加载...",
    "Not supported by the server" : "服务器不支持",
    "{usage} of {limit} used" : "已使用{usage} / {limit}",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "{email} 的账号和缓存的电子邮件数据将从 Nextcloud 中删除，但不会从您的电子邮件提供商那里删除。",
    "Remove account {email}" : "移除账号 {email}",
    "Remove {email}" : "移除 {email}",
    "Show all subscribed mailboxes" : "显示所有订阅的邮箱",
    "Show all mailboxes" : "显示所有邮箱",
    "Collapse mailboxes" : "折叠邮箱",
    "Mark all as read" : "标记所有为已读",
    "Mark all messages of this mailbox as read" : "将此邮箱中的所有消息都标记为已读",
    "Add submailbox" : "添加子邮箱",
    "Edit name" : "编辑名称",
    "Clear cache" : "清空缓存",
    "Clear locally cached data, in case there are issues with synchronization." : "万一同步出现问题，请清除本地缓存的数据。",
    "Subscribed" : "已订阅",
    "Sync in background" : "后台同步",
    "Delete mailbox" : "删除邮箱",
    "The mailbox and all messages in it will be deleted." : "邮箱和其中的所有邮件都将被删除。",
    "Delete mailbox {name}" : "删除邮箱 {name}",
    "An error occurred, unable to rename the mailbox." : "发生错误，无法重命名邮箱。",
    "_{total} message_::_{total} messages_" : ["{total} 条消息"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["总共 {total} 封邮件，{unread} 封未读邮件"],
    "New message" : "新建消息",
    "No message selected" : "没有选择消息",
    "Message" : "消息",
    "Oh Snap!" : "噢！",
    "Delete" : "删除",
    "Contacts with this address" : "使用此地址的联系人 ",
    "Add to Contact" : "添加到联系人",
    "New Contact" : "新联系人",
    "Copy to clipboard" : "复制到剪贴板",
    "Contact name …" : "联系人姓名 …",
    "Add" : "新增",
    "Tags" : "标签",
    "Select tags" : "选择标签",
    "Clear" : "清空",
    "Search" : "搜索",
    "Date" : "日期",
    "Disabled" : "已禁用",
    "Enabled" : "已启用",
    "Sieve Host" : "Sieve 主机",
    "Sieve Security" : "Sieve 安全性",
    "Sieve Port" : "Sieve 端口",
    "Sieve Credentials" : "Sieve 凭据",
    "IMAP Credentials" : "IMAP 凭据",
    "Custom" : "自定义",
    "Sieve User" : "Sieve 用户",
    "Sieve Password" : "Sieve 密码",
    "Save sieve settings" : "保存 sieve 设置",
    "Save sieve script" : "保存 sieve 脚本",
    "Signature …" : "签名...",
    "Save signature" : "保存签名",
    "Place signature above quoted text" : "把签名放在引用文本上方",
    "Add default tags" : "添加默认标签",
    "Rename tag" : "重命名标签",
    "Saving new tag name …" : "保存新标签名中 …",
    "Set" : "设置",
    "Unset" : "取消设置",
    "Add tag" : "添加标签",
    "Saving tag …" : "正在保存标签 …",
    "Tag already exists" : "标签已存在",
    "An error occurred, unable to create the tag." : "发生了一个错误，无法创建标签",
    "An error occurred, unable to rename the tag." : "发生错误，无法重命名标签",
    "Could not load your message thread" : "无法加载您的消息线线程",
    "Mark as unread" : "标为未读",
    "Mark as read" : "标为已读",
    "Delete message" : "删除消息",
    "Not found" : "没有找到",
    "Remove" : "删除",
    "No senders are trusted at the moment." : "当前没有发件人是受信任的",
    "Could not remove trusted sender {sender}" : "无法删除受信任的发件人 {sender} ",
    "individual" : "个别的",
    "domain" : "域名",
    "(organizer)" : "（组织者）",
    "Untitled event" : "无标题事件",
    "Import into {calendar}" : "导入到 {calendar}",
    "Event imported into {calendar}" : "事件导入到 {calendar}",
    "Airplane" : "飞机",
    "Reservation {id}" : "预订 {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{flightNr} 航班从 {depAirport} 飞往 {arrAirport}",
    "Train" : "火车",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} 从 {depStation} 到 {arrStation}",
    "Train from {depStation} to {arrStation}" : "火车从 {depStation} 到 {arrStation}",
    "Mail app" : "邮件应用",
    "The mail app allows users to read mails on their IMAP accounts." : "邮件应用允许用户阅读其 IMAP 账号中的邮件。",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "在这里你可以找到实例范围的设置。用户特定的设置在应用本身里（左下角）。",
    "Account provisioning" : "账户开通",
    "A provisioning configuration will provision all accounts with a matching email address." : "服务开通配置将给所有帐户提供匹配的电子邮件地址。",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "在服务开通域字段中使用通配符 (*) 将创建一个适用于所有用户的配置，倘若他们不匹配其他配置。",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "在开通机制中，特定的域配置的优先级高于通配符域配置。",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "如果在用户已经被提供了另一个配置之后找到了新的匹配的配置，则新配置具有更高优先级，将替代原先配置。",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "每个域只能有一个配置，并且只有一个通配符域配置。 ",
    "These settings can be used in conjunction with each other." : "这些设置可以相互结合使用。 ",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "如果您只想为所有用户提供一个域，请使用通配符(*)。",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "只有当您为组织的 Nextcloud 和邮件服务器使用相同的用户后端时，此设置才最有意义。",
    "Provisioning Configurations" : "账户开通配置",
    "Add new config" : "添加新配置",
    "Provision all accounts" : "开通所有账户",
    "Anti Spam Service" : "反垃圾邮件服务",
    "You can set up an anti spam service email address here." : "你可以在此设置反垃圾邮件服务的电邮地址。",
    "Any email that is marked as spam will be sent to the anti spam service." : "任何被标记为垃圾邮件的电子邮件将被发送到反垃圾邮件服务",
    "Successfully updated config for \"{domain}\"" : "成功更新了  \"{domain}\" 的配置",
    "Error saving config" : "保存配置时出错",
    "Saved config for \"{domain}\"" : "已保存 \"{domain}\" 的配置",
    "Could not save provisioning setting" : "无法保存服务开通设置",
    "There was an error when provisioning accounts." : "开通账户时发生一个错误",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "成功删除和没收了  \"{domain}\" 的账户",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "删除和没收  \"{domain}\" 账户时出错",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["成功开通了 {count} 个账户"],
    "Anti Spam" : "反垃圾邮件",
    "Add the email address of your anti spam report service here." : "在此添加反垃圾邮件报告服务的电子邮件地址。",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "使用此设置时，当用户单击“标记为垃圾邮件”时，将向垃圾邮件报告服务器发送报告电子邮件。",
    "The original message will be attached as a \"message/rfc822\" attachment." : "原始消息将作为 “message/rfc822” 附件附加。",
    "\"Mark as Spam\" Email Address" : "“标记为垃圾邮件”电子邮件地址",
    "\"Mark Not Junk\" Email Address" : "“标记为非垃圾邮件”的电子邮件地址",
    "Reset" : "重置",
    "Successfully set up anti spam email addresses" : "成功设置反垃圾邮件电邮地址",
    "Error saving anti spam email addresses" : "保存反垃圾邮件地址出错",
    "Successfully deleted anti spam reporting email" : "成功删除反垃圾邮件报告电子邮件",
    "Error deleting anti spam reporting email" : "删除反垃圾邮件报告邮件出错",
    "Domain Match: {provisioningDomain}" : "域名匹配：{provisioningDomain}",
    "Email: {email}" : "电子邮件：{email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} 在 {host}:{port} ({ssl} 加密)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} 在 {host}:{port} ({ssl} 加密)",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve：{user} 位于 {host}:{port} ({ssl} encryption)",
    "Configuration for \"{provisioningDomain}\"" : "\"{provisioningDomain}\" 的配置",
    "General" : "常规",
    "Provisioning domain" : "开通域名",
    "Email address template" : "电子邮件地址模板",
    "IMAP" : "IMAP",
    "User" : "用户",
    "Host" : "主机",
    "Port" : "端口",
    "SMTP" : "SMTP",
    "Sieve" : "Sieve",
    "Enable sieve integration" : "启用 sieve 集成",
    "LDAP aliases integration" : "LDAP 别名集成",
    "Enable LDAP aliases integration" : "启用 LDAP 别名集成",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "LDAP 别名集成从配置的 ldap 目录读取属性以提供电子邮件别名。",
    "LDAP attribute for aliases" : "别名的 LDAP 属性",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "提供电子邮件别名的多值属性。为每个值创建一个别名。存在于 Nextcloud 中但 LDAP 目录中不存在的别名将被删除。",
    "Save Config" : "保存配置",
    "Unprovision & Delete Config" : "取消开通 & 删除配置",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% 和 %EMAIL% 将被用户的 UID 及邮箱地址所代替",
    "With the settings above, the app will create account settings in the following way:" : "使用上述设置，该应用将通过以下方式创建账号设置：",
    "Keyboard shortcut" : "键盘快捷键",
    "Keyboard shortcuts" : "键盘快捷方式",
    "Speed up your Mail experience with these quick shortcuts." : "利用这些快捷方式使您的邮件使用过程更加迅捷",
    "Compose new message" : "撰写新消息",
    "Newer message" : "更新的信息",
    "Older message" : "更早的信息",
    "Toggle star" : "切换星标",
    "Toggle unread" : "切换未读",
    "Refresh" : "刷新",
    "Connect your mail account" : "连接您的邮件账号",
    "Itinerary for {type} is not supported yet" : "尚不支持 {type} 类型的行程",
    "All" : "全部",
    "Archive" : "归档",
    "Drafts" : "草稿",
    "Favorites" : "收藏",
    "Priority inbox" : "优先收件箱",
    "All inboxes" : "所有收件箱",
    "Inbox" : "收件箱",
    "Junk" : "垃圾邮件",
    "Sent" : "已发送",
    "Trash" : "废件箱",
    "Error while sharing file" : "共享文件时出错",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["来自 {from} 的 %n 条新消息"],
    "Nextcloud Mail" : "Nextcloud 邮件",
    "Attachments were not copied. Please add them manually." : "附件没有被复制。请手动添加。",
    "Message sent" : "消息已发送",
    "Could not load {tag}{name}{endtag}" : "无法加载 {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "加载 {tag}{name}{endtag} 时出现问题",
    "Could not load your message" : "无法加载您的消息",
    "Could not load the desired message" : "无法加载想要的消息",
    "Could not load the message" : "无法加载该消息",
    "Error loading message" : "载入消息时发生错误",
    "Forwarding to %s" : "转发给 %s",
    "Click here if you are not automatically redirected within the next few seconds." : "如果您在接下来几秒钟内未被自动重定向，请点击此处。",
    "Redirect" : "重定向",
    "The link leads to %s" : "链接指向 %s",
    "Continue to %s" : "继续 %s"
},
"nplurals=1; plural=0;");
